<?xml version="1.0" ?><!DOCTYPE TS><TS language="it_IT" version="2.0">
<context>
    <name>QuickLaunchButton</name>
    <message>
        <source>Move left</source>
        <translation>Sposta a sinistra</translation>
    </message>
    <message>
        <source>Move right</source>
        <translation>Sposta a destra</translation>
    </message>
    <message>
        <source>Remove from quicklaunch</source>
        <translation>Rimuovi da Avvio rapido</translation>
    </message>
</context>
<context>
    <name>RazorQuickLaunch</name>
    <message>
        <source>Drop Error</source>
        <translation>Errore di spostamento</translation>
    </message>
    <message>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Il file/URL &apos;%1&apos; in questo momento non può essere inserito in Avvio rapido</translation>
    </message>
</context>
</TS>